==> distanceutils-0.3.3-py3-none-any.whl: distance/levelinfos.py <==
"""LevelInfos .bytes support."""


from .bytes import BytesModel, MAGIC_2, MAGIC_12, S_FLOAT
from .base import (
    BaseObject, Fragment,
    BASE_FRAG_PROBER,
    ForwardFragmentAttrs,
)
from .printing import format_duration
from .constants import Mode
from .prober import BytesProber


FTYPE_LEVELINFOS = 'LevelInfos'


FRAG_PROBER = BytesProber()

FRAG_PROBER.extend(BASE_FRAG_PROBER)


class Entry(BytesModel):

    level_name = None
    level_path = None
    level_basename = None
    modes = ()
    medal_times = ()
    medal_scores = ()

    def _read(self, dbytes):
        self.level_name = dbytes.read_str()
        self.level_path = dbytes.read_str()
        self.level_basename = dbytes.read_str()
        dbytes.read_bytes(16)
        dbytes.require_equal_uint4(MAGIC_12)
        num_modes = dbytes.read_uint4()
        self.modes = modes = {}
        for _ in range(num_modes):
            mode = dbytes.read_uint4()
            modes[mode] = dbytes.read_byte()
        self.medal_times = times = []
        self.medal_scores = scores = []
        for _ in range(4):
            times.append(dbytes.read_struct(S_FLOAT)[0])
            scores.append(dbytes.read_int4())
        dbytes.read_bytes(25)

    def _print_data(self, p):
        p(f"Level name: {self.level_name!r}")
        p(f"Level path: {self.level_path!r}")
        p(f"Level basename: {self.level_basename!r}")
        if self.modes:
            mode_str = ', '.join(Mode.to_name(m) for m, e in sorted(self.modes.items()) if e)
            p(f"Enabled modes: {mode_str or 'None'}")
        if self.medal_times:
            times_str = ', '.join(format_duration(t) for t in reversed(self.medal_times))
            p(f"Medal times: {times_str}")
        if self.medal_scores:
            scores_str = ', '.join(str(s) for s in reversed(self.medal_scores))
            p(f"Medal scores: {scores_str}")


@FRAG_PROBER.fragment(MAGIC_2, 0x97, 0)
class LevelInfosFragment(Fragment):

    version = None
    levels = ()

    def _read_section_data(self, dbytes, sec):
        self.version = sec.version
        num_entries = dbytes.read_uint8()
        self.levels = Entry.lazy_n_maybe(dbytes, num_entries)


@ForwardFragmentAttrs(LevelInfosFragment, dict(levels=(), version=None))
class LevelInfos(BaseObject):

    fragment_prober = FRAG_PROBER

    def _read(self, dbytes):
        self._require_type(FTYPE_LEVELINFOS)
        BaseObject._read(self, dbytes)

    def _print_data(self, p):
        p(f"Version: {self.version}")
        p(f"Level entries: {len(self.levels)}")
        with p.tree_children():
            for entry in self.levels:
                p.tree_next_child()
                p.print_data_of(entry)


# vim:set sw=4 ts=8 sts=4 et sr ft=python fdm=marker tw=0:

==> distanceutils-0.4.1-py3-none-any.whl: distance/levelinfos.py <==
"""LevelInfos .bytes support."""


from .bytes import BytesModel, MAGIC_2, MAGIC_12, S_FLOAT
from .base import (
    BaseObject, Fragment,
    BASE_FRAG_PROBER,
    ForwardFragmentAttrs,
)
from .printing import format_duration
from .constants import Mode
from .prober import BytesProber


FTYPE_LEVELINFOS = 'LevelInfos'


FRAG_PROBER = BytesProber()

FRAG_PROBER.extend(BASE_FRAG_PROBER)


class Entry(BytesModel):

    level_name = None
    level_path = None
    level_basename = None
    modes = ()
    medal_times = ()
    medal_scores = ()

    def _read(self, dbytes):
        self.level_name = dbytes.read_str()
        self.level_path = dbytes.read_str()
        self.level_basename = dbytes.read_str()
        dbytes.read_bytes(16)
        dbytes.require_equal_uint4(MAGIC_12)
        num_modes = dbytes.read_uint4()
        self.modes = modes = {}
        for _ in range(num_modes):
            mode = dbytes.read_uint4()
            modes[mode] = dbytes.read_byte()
        self.medal_times = times = []
        self.medal_scores = scores = []
        for _ in range(4):
            times.append(dbytes.read_struct(S_FLOAT)[0])
            scores.append(dbytes.read_int4())
        dbytes.read_bytes(25)

    def _print_data(self, p):
        p(f"Level name: {self.level_name!r}")
        p(f"Level path: {self.level_path!r}")
        p(f"Level basename: {self.level_basename!r}")
        if self.modes:
            mode_str = ', '.join(Mode.to_name(m) for m, e in sorted(self.modes.items()) if e)
            p(f"Enabled modes: {mode_str or 'None'}")
        if self.medal_times:
            times_str = ', '.join(format_duration(t) for t in reversed(self.medal_times))
            p(f"Medal times: {times_str}")
        if self.medal_scores:
            scores_str = ', '.join(str(s) for s in reversed(self.medal_scores))
            p(f"Medal scores: {scores_str}")


@FRAG_PROBER.fragment(MAGIC_2, 0x97, 0)
class LevelInfosFragment(Fragment):

    version = None
    levels = ()

    def _read_section_data(self, dbytes, sec):
        self.version = sec.version
        num_entries = dbytes.read_uint8()
        self.levels = Entry.lazy_n_maybe(dbytes, num_entries)


@ForwardFragmentAttrs(LevelInfosFragment, levels=(), version=None)
class LevelInfos(BaseObject):

    fragment_prober = FRAG_PROBER

    def _read(self, dbytes):
        self._require_type(FTYPE_LEVELINFOS)
        BaseObject._read(self, dbytes)

    def _print_data(self, p):
        p(f"Version: {self.version}")
        p(f"Level entries: {len(self.levels)}")
        with p.tree_children():
            for entry in self.levels:
                p.tree_next_child()
                p.print_data_of(entry)


# vim:set sw=4 ts=8 sts=4 et sr ft=python fdm=marker tw=0:
